@@ -21,7 +21,7 @@ package Spreadsheet::Read;
 use strict;
 use warnings;
 
-our $VERSION = "0.24";
+our $VERSION = "0.25";
 sub  Version { $VERSION }
 
 use Exporter;
@@ -34,8 +34,8 @@ use Data::Dumper;
 
 my @parsers = (
     [ csv	=> "Text::CSV_XS"		],
-    [ csv	=> "Text::CSV_PP"		],
-#   [ csv	=> "Text::CSV"			],	# NYI
+    [ csv	=> "Text::CSV_PP"		], # Version 1.05 and up
+    [ csv	=> "Text::CSV"			], # Version 1.00 and up
     [ ods	=> "Spreadsheet::ReadSXC"	],
     [ sxc	=> "Spreadsheet::ReadSXC"	],
     [ xls	=> "Spreadsheet::ParseExcel"	],
